==> rosegarden-1.6.1.tar.bz2: rosegarden-1.6.1/src/commands/segment/SetTriggerSegmentBaseVelocityCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2007
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_SETTRIGGERSEGMENTBASEVELOCITYCOMMAND_H_
#define _RG_SETTRIGGERSEGMENTBASEVELOCITYCOMMAND_H_

#include "base/TriggerSegment.h"
#include <kcommand.h>




namespace Rosegarden
{

class Composition;


class SetTriggerSegmentBaseVelocityCommand : public KNamedCommand
{
public:
    SetTriggerSegmentBaseVelocityCommand(Composition *composition,
                                      TriggerSegmentId id,
                                      int newVelocity);
    virtual ~SetTriggerSegmentBaseVelocityCommand();
    
    virtual void execute();
    virtual void unexecute();

protected:
    Composition *m_composition;
    TriggerSegmentId m_id;
    int m_newVelocity;
    int m_oldVelocity;
};



}

#endif

==> rosegarden_11.11.42.orig.tar.bz2: rosegarden-11.11.42/src/commands/segment/SetTriggerSegmentBaseVelocityCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2011 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_SETTRIGGERSEGMENTBASEVELOCITYCOMMAND_H_
#define _RG_SETTRIGGERSEGMENTBASEVELOCITYCOMMAND_H_

#include "base/TriggerSegment.h"
#include "document/Command.h"

#include <QCoreApplication>


namespace Rosegarden
{

class Composition;


class SetTriggerSegmentBaseVelocityCommand : public NamedCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::SetTriggerSegmentBaseVelocityCommand)

public:
    SetTriggerSegmentBaseVelocityCommand(Composition *composition,
                                      TriggerSegmentId id,
                                      int newVelocity);
    virtual ~SetTriggerSegmentBaseVelocityCommand();
    
    virtual void execute();
    virtual void unexecute();

protected:
    Composition *m_composition;
    TriggerSegmentId m_id;
    int m_newVelocity;
    int m_oldVelocity;
};



}

#endif
